//---------------------------------------
// Speed Boat - Script By Destiny - Model By Racer
//---------------------------------------

datablock WheeledVehicleTire(boatTire)
{
   // Tires act as springs and generate lateral and longitudinal
   // forces to move the vehicle. These distortion/spring forces
   // are what convert wheel angular velocity into forces that
   // act on the rigid body.
   shapeFile = "./emptyWheel.dts";
   staticFriction = 0.0;
   kineticFriction = 0.0;

   // Spring that generates lateral tire forces
   lateralForce = 0;
   lateralDamping = 0;
   lateralRelaxation = 1;

   // Spring that generates longitudinal tire forces
   longitudinalForce = 0;
   longitudinalDamping = 0;
   longitudinalRelaxation = 1;
};

datablock WheeledVehicleSpring(boatSpring)
{
   // Wheel suspension properties
   length = 2;             // Suspension travel
   force = 195; //3000;              // Spring force
   damping = 60; //600;             // Spring damping
   antiSwayForce = 0; //3;         // Lateral anti-sway force
};

datablock WheeledVehicleData(SpeedBoatVehicle)
{
	//tagged fields
	doSimpleDismount = true;		//just unmount the player, dont look for a free space

   category = "Vehicles";
   shapeFile = "./speedboat.dts";
   emap = true;
   minMountDist = 3;
   
   numMountPoints = 2;
   mountThread[0] = "sit";
   mountThread[1] = "sit";

   maxDamage = 200.0;
   destroyedLevel = 0.5;

   maxSteeringAngle = 1;  // Maximum steering angle, should match animation
   tireEmitter = VehicleTireEmitter; // All the tires use the same dust emitter

   // 3rd person camera settings
   cameraRoll = false;         // Roll the camera with the vehicle?
   cameraMaxDist = 11;         // Far distance from vehicle
   cameraOffset = 6.8;        // Vertical offset from camera mount point
   cameraLag = 0.0;           // Velocity lag of camera
   cameraDecay = 1.75;  //0.75;      // Decay per sec. rate of velocity lag
   cameraTilt = 0.3201; //tilt adjustment for camera: ~20 degrees down

   // Rigid Body
   mass = 60;		//3100 lbs
   density = 0.3;
   massCenter = "0 0 0";    // Center of mass for rigid body
   massBox = "0 0 0";         // Size of box used for moment of inertia,
                              // if zero it defaults to object bounding box
   drag = 0.3;                // Drag coefficient
   bodyFriction = 0.1;
   bodyRestitution = 0;
   minImpactSpeed = 3;        // Impacts over this invoke the script callback
   softImpactSpeed = 3;       // Play SoftImpact Sound
   hardImpactSpeed = 10;      // Play HardImpact Sound
   integration = 1;           // Physics integration: TickSec/Rate
   collisionTol = 0.1;        // Collision distance tolerance
   contactTol = 0.01;          // Contact velocity tolerance


   isSled = true;	//if its a sled, the wing surfaces dont work unless its on the ground
	
   // Engine
   engineTorque = 200000;       // Engine power
   engineBrake = 25;         // Braking when throttle is 0
   brakeTorque = 80000;        // When brakes are applied
   maxWheelSpeed = 50;        // Engine scale by current speed / max speed

	forwardThrust		= 800;
	reverseThrust		= 500;
	lift			= 0;
	maxForwardVel		= 60;
	maxReverseVel		= 10;
	horizontalSurfaceForce	= 50;   // Horizontal center "wing" (provides "bite" into the wind for climbing/diving and turning)
	verticalSurfaceForce	= 1000; 
	rollForce		= 0;
	yawForce		= 10000;
	pitchForce		= 0;
	rotationalDrag		= 3;
	stallSpeed		= 0;

	jumpForce	= 10000; //havent added this into code yet.
	

   // Energy
   maxEnergy = 100;
   jetForce = 3000;
   minJetEnergy = 30;
   jetEnergyDrain = 2;

   // Sounds
//   jetSound = ScoutThrustSound;
   //engineSound = "";
   //squealSound = sprayFireSound;
   //softImpactSound = Impact1ASound;
   hardImpactSound = Impact1BSound;
   //wheelImpactSound = Impact1BSound;

//   explosion = VehicleExplosion;
   
   steeringAutoReturn = true;
   steeringAutoReturnRate = 8;
   steeringAutoReturnMaxSpeed = 10;
   steeringUseStrafeSteering = true;
   steeringStrafeSteeringRate = 10;
 
   uiName = "Speed Boat ";
	rideable = true;
		lookUpLimit = 0;
		lookDownLimit = 0;

	paintable = true;
   
   damageEmitter[0] = VehicleBurnEmitter;
	damageEmitterOffset[0] = "0.0 0.0 0.0 ";
	damageLevelTolerance[0] = 0.99;

   damageEmitter[1] = VehicleBurnEmitter;
	damageEmitterOffset[1] = "0.0 0.0 0.0 ";
	damageLevelTolerance[1] = 1.0;

   numDmgEmitterAreas = 1;

   initialExplosionProjectile = VehicleExplosionProjectile;
   initialExplosionOffset = 0;         //offset only uses a z value for now

   burnTime = 4000;

   finalExplosionProjectile = VehicleFinalExplosionProjectile;
   finalExplosionOffset = 0.5;          //offset only uses a z value for now

   minRunOverSpeed    = 4;   //how fast you need to be going to run someone over (do damage)
   runOverDamageScale = 8;   //when you run over someone, speed * runoverdamagescale = damage amt
   runOverPushScale   = 1.2; //how hard a person you're running over gets pushed

   //protection for passengers
   protectPassengersBurn   = false;  //protect passengers from the burning effect of explosions?
   protectPassengersRadius = true;  //protect passengers from radius damage (explosions) ?
   protectPassengersDirect = false; //protect passengers from direct damage (bullets) ?
};

function SpeedBoatVehicle::onAdd(%this,%obj)
{
	//mount the nothing tire and ski spring
	%obj.setWheelTire(0, boattire);
	%obj.setWheelTire(1, boattire);
	%obj.setWheelTire(2, boattire);
	%obj.setWheelTire(3, boattire);

	%obj.setWheelSpring(0, boatSpring);
	%obj.setWheelSpring(1, boatSpring);
	%obj.setWheelSpring(2, boatSpring);
	%obj.setWheelSpring(3, boatSpring);
}	

